.. include:: references.txt

.. _gala-user-guide:

**********
User Guide
**********

The user guide contains comprehensive descriptions of all functions and
classes available in ``gala``, with inline examples and demonstrations.
This documentation serves as reference material, while the :ref:`gala-tutorials`
show how ``gala`` components work together for realistic research applications.

.. toctree::
    :maxdepth: 1

    conventions
    coordinates/index
    integrate/index
    potential/index
    dynamics/index
    units
    util
    interop

.. toctree::
    :hidden:

    glossary


Recent additions and changes
============================

.. toctree::
    :maxdepth: 2

    whatsnew/index
